==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebColumnResizeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnResizeEventArgsDetailDescriptionMetadata } from "./WebColumnResizeEventArgsDetailDescriptionMetadata";
import { WebColumnResizeEventArgsDescription } from "./WebColumnResizeEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnResizeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnResizeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnResizeEventArgsDescriptionMetadata.a == null) {
                WebColumnResizeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnResizeEventArgsDescriptionMetadata.c(WebColumnResizeEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebColumnResizeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnResizeEventArgsDescriptionMetadata.a);
            WebColumnResizeEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnResizeEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebColumnResizeEventArgsDetail");
        }
        static d(a) {
            WebColumnResizeEventArgsDescriptionMetadata.b(a);
            a.aa("WebColumnResizeEventArgs", () => new WebColumnResizeEventArgsDescription());
            a.z("WebColumnResizeEventArgs", WebColumnResizeEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnResizeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnResizeEventArgsDescriptionMetadata, 'WebColumnResizeEventArgsDescriptionMetadata');
    WebColumnResizeEventArgsDescriptionMetadata.a = null;
    return WebColumnResizeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnResizeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnResizeEventArgsDetailDescriptionMetadata } from "./WebColumnResizeEventArgsDetailDescriptionMetadata";
import { WebColumnResizeEventArgsDescription } from "./WebColumnResizeEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnResizeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnResizeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnResizeEventArgsDescriptionMetadata.a == null) {
                WebColumnResizeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnResizeEventArgsDescriptionMetadata.c(WebColumnResizeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnResizeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnResizeEventArgsDescriptionMetadata.a);
            WebColumnResizeEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnResizeEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnResizeEventArgsDetail");
        }
        static d(a) {
            WebColumnResizeEventArgsDescriptionMetadata.b(a);
            a.ac("WebColumnResizeEventArgs", () => new WebColumnResizeEventArgsDescription());
            a.ab("WebColumnResizeEventArgs", WebColumnResizeEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnResizeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnResizeEventArgsDescriptionMetadata, 'WebColumnResizeEventArgsDescriptionMetadata');
    WebColumnResizeEventArgsDescriptionMetadata.a = null;
    return WebColumnResizeEventArgsDescriptionMetadata;
})();
